// Translated by Fabio Pugliese Ornellas <fabio.ornellas@poli.usp.br>
// Portuguese from Brazil Translation
// GPLed code
// in sync version 1.87 from CVS 2002-02-04

// ========================= MPlayer help ===========================

#ifdef HELP_MP_DEFINE_STATIC
static char help_text[]=
"Uso:   mplayer [opes] [url|caminho/]nome-do-arquivo\n"
"\n"
"Opes bsicas: (lista completa na pgina do manual)\n"
" -vo <drv[:dev]> seleciona o driver de sada de vdeo & dispositivo\n"
"                 ('-vo help' para listar)\n"
" -ao <drv[:dev]> seleciona o driver de sada de audio & dispositivo\n"
"                 ('-vo help' para listar)\n"
#ifdef HAVE_VCD
" -vcd <numtrilha> reproduz trilha de VCD (Video CD) do dispositivo em vez de um\n"
"                 arquivo\n"
#endif
#ifdef HAVE_LIBCSS
" -dvdauth <dev>  especifica o dispositivo de DVD para autenticao (para discos\n"
"                 encriptados)\n"
#endif
#ifdef USE_DVDREAD
" -dvd <numttilo> reproduz ttulo de DVD do dispositivo em vez de um arquivo\n"
" -alang/-slang   seleciona o idioma/legenda do DVD (pelo cdigo pas de duas\n"
"                 letras)\n"
#endif
" -ss <tempopos>  busca para a posio dada (segundos ou hh:mm:ss)\n"
" -nosound        no reproduz som\n"
" -fs             reproduo em tela cheia (ou -vm, -zoom, detalhes na pgina do\n"
"                 manual)\n"
" -x <x> -y <y>   especifica a resoluo da tela (para uso com -vm ou -zoom)\n"
" -sub <arquivo>  especifica o arquivo de legenda a usar (veja tambm -subfps,\n"
"                 -subdelay)\n"
" -playlist <arquivo> especifica o aruqivo com a lista de reproduo\n"
" -vid x -aid y   seleciona a trilha de vdeo (x) e audio (y) a reproduzir\n"
" -fps x -srate y muda a taxa do vdeo (x quadros por segundo) e audio (y Hz)\n"
" -pp <qualidade> habilita filtro de ps processamento (veja detalhes na pgina\n"
"                 do manual)\n"
" -framedrop      habilita descarte de quadros (para mquinas lentas)\n"
"\n"
"Teclas bsicas: (lista completa na pginal do manual, cheque tambm input.conf)\n"
" <-  ou  ->      retorna/avana 10 segundos\n"
" cima ou baixo   retorna/avana 1 minuto\n"
" pgup ou pgdown  retorna/avana 10 minutos\n"
" < ou >          retorna/avana na lista de reproduo\n"
" p ou ESPAO     pausa o filme (pressione qualquer tecla para continuar)\n"
" q ou ESC        para a reproduo e sai do programa\n"
" + ou -          ajusta o atraso do audio de +/- 0.1 segundo\n"
" o               alterna modo OSD: nenhum / busca / busca+cronmetro\n"
" * ou /          aumenta ou diminui o volume pcm\n"
" z ou x          ajusta o atraso da legenda de +/- 0.1 segundo\n"
" r ou t          posio da legenda para cima/baixo, veja tambm -vop expand\n"
"\n"
"* VEJA A PGINA DO MANUAL PARA DETALHES, FUTURAS (AVANADAS) OPES E TECLAS *\n"
"\n";
#endif

// ========================= MPlayer messages ===========================

// mplayer.c:

#define MSGTR_Exiting "\nSaindo... (%s)\n"
#define MSGTR_Exit_quit "Sair"
#define MSGTR_Exit_eof "Fim do arquivo"
#define MSGTR_Exit_error "Erro fatal"
#define MSGTR_IntBySignal "\nMPlayer interrompido por sinal %d no mdulo %s\n"
#define MSGTR_NoHomeDir "Diretrio HOME no encontrado.\n"
#define MSGTR_GetpathProblem "Problema em get_path(\"config\")\n"
#define MSGTR_CreatingCfgFile "Criando arquivo de configurao: %s\n"
#define MSGTR_InvalidVOdriver "Nome do driver de sada de vdeo invlido: %s\nUse '-vo help' para listar os drivers disponveis.\n"
#define MSGTR_InvalidAOdriver "Nome do driver de sada de audio invlido: %s\nUse '-ao help' para listar os drivers disponveis.\n"
#define MSGTR_CopyCodecsConf "(Copie/link etc/codecs.conf da fonte do MPlayer para ~/.mplayer/codecs.conf)\n"
#define MSGTR_BuiltinCodecsConf "Usando codecs.conf interno padro\n"
#define MSGTR_CantLoadFont "Impossvel carregar fonte: %s\n"
#define MSGTR_CantLoadSub "Impossvel carregar legendas: %s\n"
#define MSGTR_ErrorDVDkey "Erro processando a chave do DVD.\n"
#define MSGTR_CmdlineDVDkey "A chave do DVD requisitada est sendo usada para \"descrambling\".\n"
#define MSGTR_DVDauthOk "Sequncia de autenticao do DVD parece estar OK.\n"
#define MSGTR_DumpSelectedStreamMissing "dump: FATAL: faltando trilha selecionada!\n"
#define MSGTR_CantOpenDumpfile "Impossvel abrir arquivo de dump.\n"
#define MSGTR_CoreDumped "core dumped ;)\n"
#define MSGTR_FPSnotspecified "Quadros por segundo no especificado no cabealho ou invlido, use a opo -fps.\n"
#define MSGTR_TryForceAudioFmtStr "Tentando forar a famlia %s do driver do codec de audio...\n"
#define MSGTR_CantFindAfmtFallback "Codec de audio para a famlia de driver forado no encontrado, voltando a outros drivers.\n"
#define MSGTR_CantFindAudioCodec "Codec para o format de audio 0x%X no encontrado!\n"
#define MSGTR_TryUpgradeCodecsConfOrRTFM "*** Tente atualizar %s de etc/codecs.conf\n*** Se ainda no funcionar, leia DOCS/codecs.html!\n"
#define MSGTR_CouldntInitAudioCodec "Impssvel inicializar o codec de audio! -> sem som\n"
#define MSGTR_TryForceVideoFmtStr "Tentando forar a famlia %s do driver do codec de vdeo...\n"
#define MSGTR_CantFindVideoCodec "Impossvel encontrar codec que se iguale ao -vo selecionado e ao formato de video 0x%X!\n"
#define MSGTR_VOincompCodec "O dispositivo de sada de vdeo selecionado  incompatvel com este codec.\n"
#define MSGTR_CannotInitVO "FATAL: Impossvel inicializar o driver de vdeo.\n"
#define MSGTR_CannotInitAO "Impossvel abrir/inicializar o dispositivo de audio -> sem som\n"
#define MSGTR_StartPlaying "Inciando reproduo...\n"

#define MSGTR_SystemTooSlow "\n\n"\
"          ***************************************************\n"\
"          * Seu sistema  muito LENTO para reproduzir isto! *\n"\
"          ***************************************************\n\n"\
"Possveis razes, problemas, solues:\n"\
"- Mais comum: driver de _audio_ quebrado/falho\n"\
"  - Tente -ao sdl ou use ALSA 0.5 ou a emulao OSS do ALSA 0.9.\n"\
"  - Experimente com diferente valores para -autosync, 30  um bom comeo.\n"\
"- Sada de vdeo lenta\n"\
"  - Tente um driver diferente -vo (-vo help para listar) ou tente -framedrop!\n"\
"- CPU Lento\n"\
"  - No tente reproduzir um DVD/DivX grande em um CPU lento! Tente\n"\
"    -hardframedrop.\n"\
"- Arquivo corrompido\n"\
"  - Tente vrias combinaes de -nobps -ni -forceidx -mc 0.\n"\
"- Mdia lenta (montagens NFS/SMB, DVD, VCD etc...)\n"\
"  - Tente -cache 8192.\n"\
"- Voc est usando -cache para reproduzir um arquivo AVI no-entrelaado?\n"\
"  - Tente -nocache.\n"\
"Leia DOCS/video.html e DOCS/sound.html para dicas de ajuste/velocidade.\n"\
"Se nenhum destes ajudar voc, leia DOCS/bugreports.html.\n\n"

#define MSGTR_NoGui "MPlayer foi compilado SEM suporte a GUI (interface grfica com o usurio)!\n"
#define MSGTR_GuiNeedsX "MPlayer GUI (interface grfica com o usurio) requer X11!\n"
#define MSGTR_Playing "Reproduzindo %s\n"
#define MSGTR_NoSound "Audio: sem som.\n"
#define MSGTR_FPSforced "FPS (quadros por segundo) forado a ser %5.3f (ftime: %5.3f)\n"
#define MSGTR_CompiledWithRuntimeDetection "Compilado com deteco de CPU em tempo real - AVISO - isto no  ideal! Para obter a melhor performance, recompile MPlayer com --disable-runtime-cpudetection\n"
#define MSGTR_CompiledWithCPUExtensions "Compilado para CPU x86 com extenes:"
#define MSGTR_AvailableVideoOutputPlugins "Plugins de sada de vdeo disponveis:\n"
#define MSGTR_AvailableVideoOutputDrivers "Drivers de sada de vdeo disponveis:\n"
#define MSGTR_AvailableAudioOutputDrivers "Drivers de sada de audio disponveis:\n"
#define MSGTR_AvailableAudioCodecs "Codecs de audio disponveis:\n"
#define MSGTR_AvailableVideoCodecs "Codecs de vdeo disponveis:\n"
#define MSGTR_AvailableAudioFm "\nFamlias/drivers de codec de audio disponveis (compilados):\n"
#define MSGTR_AvailableVideoFm "\nFamlias/drivers de codec de vdeo disponveis (compilados):\n"
#define MSGTR_UsingRTCTiming "Usando regulao de tempo Linux hardware RTC (%ldHz)\n"
#define MSGTR_CannotReadVideoProperties "Video: impossvel ler propriedades\n"
#define MSGTR_NoStreamFound "Trilha no encontrada\n"
#define MSGTR_InitializingAudioCodec "Inicializando codec de audio...\n"
#define MSGTR_ErrorInitializingVODevice "Erro abrindo/inicializando o dispositivo da sada de vdeo (-vo)!\n"
#define MSGTR_ForcedVideoCodec "Codec de vdeo forado: %s\n"
#define MSGTR_ForcedAudioCodec "Codec de audio forado: %s\n"
#define MSGTR_AODescription_AOAuthor "AO: Descrio: %s\nAO: Autor: %s\n"
#define MSGTR_AOComment "AO: Comentrio: %s\n"
#define MSGTR_Video_NoVideo "Vdeo: sem vdeo\n"
#define MSGTR_NotInitializeVOPorVO "\nFATAL: Impossvel inicializar os filtros de vdeo (-vop) ou a sada de vdeo (-vo)!\n"
#define MSGTR_Paused "\n================= PAUSADO =================\r"
#define MSGTR_PlaylistLoadUnable "\nIncapaz de carregar a lista de reproduo %s.\n"
#define MSGTR_Exit_SIGILL_RTCpuSel \
"- MPlayer falhou por uma 'Instruo Ilegal'.\n"\
"  Pode ser um erro no nosso novo cdigo de deteco de CPU em tempo real...\n"\
"  Por favor leia DOCS/bugreports.html.\n"
#define MSGTR_Exit_SIGILL \
"- MPlayer falhou por uma 'Instruo Ilegal'.\n"\
"  Isso frequentemente acontece quando voc o exucuta em um CPU diferente do que\n"\
"  aquele para o qual foi compilado/otimizado.\n  Verifique isso!\n"
#define MSGTR_Exit_SIGSEGV_SIGFPE \
"- MPlayer falhou por mau uso do CPU/FPU/RAM.\n"\
"  Recompile o MPlayer com --enable-debug e faa um 'gdb backtrace' e\n"\
"  'disassembly'. Para detalhes, veja DOCS/bugreports.html#crash.b.\n"
#define MSGTR_Exit_SIGCRASH \
"- MPlayer falhou. Isso no deveria acontecer.\n"\
"  Pode ser um erro no cdigo do MPlayer _ou_ em seus drivers _ou_ em sua verso\n"\
"  do gcc. Se voc acha que  culpa do MPlayer, por favor leia\n"\
"  DOCS/bugreports.html e siga as instrues. Ns no podemos e no vamos ajudar\n"\
"  a no ser que voc proveja esta informao quando reportar um possvel erro.\n"

// mencoder.c:

#define MSGTR_UsingPass3ControllFile "Usando controle de arquivo pass3: %s\n"
#define MSGTR_MissingFilename "\nFaltando nome do arquivo!\n\n"
#define MSGTR_CannotOpenFile_Device "Impossvel abrir arquivo/dispositivo\n"
#define MSGTR_ErrorDVDAuth "Erro na autenticao do DVD.\n"
#define MSGTR_CannotOpenDemuxer "Impossvel abrir \"demuxer\"\n"
#define MSGTR_NoAudioEncoderSelected "\nNenhum codificador de audio (-oac) selecionado! Selecione um ou use -nosound. Use -oac help para listar!\n"
#define MSGTR_NoVideoEncoderSelected "\nNenhum codificador de vdeo (-ovc) selecionado! Selecione um, use -ovc help para listar!\n"
#define MSGTR_InitializingAudioCodec "Inicializando codec de audio...\n"
#define MSGTR_CannotOpenOutputFile "Impossvel abrir arquivo de sada '%s'\n"
#define MSGTR_EncoderOpenFailed "Falha ao abrir o codificador\n"
#define MSGTR_ForcingOutputFourcc "Forando sada fourcc para %x [%.4s]\n"
#define MSGTR_WritingAVIHeader "Gravando cabealho do AVI...\n"
#define MSGTR_DuplicateFrames "\n%d quadro(s) duplicado(s)!\n"
#define MSGTR_SkipFrame "\npulando frame!!!    \n"
#define MSGTR_ErrorWritingFile "%s: erro gravando arquivo.\n"
#define MSGTR_WritingAVIIndex "\nGravando ndice do AVI...\n"
#define MSGTR_FixupAVIHeader "Corrigindo cabealho do AVI...\n"
#define MSGTR_RecommendedVideoBitrate "Bitrate do vdeo recomendado para CD de %s: %d\n"
#define MSGTR_VideoStreamResult "\nTrilha de vdeo: %8.3f kbit/s  (%d bps)  tamanho: %d bytes  %5.3f segundos  %d quadros\n"
#define MSGTR_AudioStreamResult "\nTrilha de audio: %8.3f kbit/s  (%d bps)  tamanho: %d bytes  %5.3f segundos\n"

// cfg-mencoder.h:

#define MSGTR_MEncoderMP3LameHelp "\n\n"\
" vbr=<0-4>     mtodo da taxa de bits varivel\n"\
"                0: cbr\n"\
"                1: mt\n"\
"                2: rh(padro)\n"\
"                3: abr\n"\
"                4: mtrh\n"\
"\n"\
" abr           taxa de bits mdia\n"\
"\n"\
" cbr           taxa de bits constante\n"\
"               Fora tambm modo de codificao CBR nos modos ABR\n"\
"               pr-selecionados subsequentes.\n"\
"\n"\
" br=<0-1024>   especifica a taxa de bits em kBit (somente CBR e ABR)\n"\
"\n"\
" q=<0-9>       qualidade (0-melhor, 9-pior) (somente para VBR)\n"\
"\n"\
" aq=<0-9>      qualidade do algortmo (0-melhor/mais lento, 9-pior/mais rpido)\n"\
"\n"\
" ratio=<1-100> taxa de compresso\n"\
"\n"\
" vol=<0-10>    configura ganho da entrada de audio\n"\
"\n"\
" mode=<0-3>    (padro: auto)\n"\
"                0: estreo\n"\
"                1: estreo-junto\n"\
"                2: canal duplo\n"\
"                3: mono\n"\
"\n"\
" padding=<0-2>\n"\
"                0: no\n"\
"                1: tudo\n"\
"                2: adaptar\n"\
"\n"\
" fast          aciona codificao rpida nos modos VBR pr-selecionados\n"\
"               subsequentes, qualidade muito baixa e altas taxas de bit.\n"\
"\n"\
" preset=<value> prov os ajustes com a mais alta qualidade.\n"\
"                 medium: codificao VBR, qualidade boa\n"\
"                 (taxa de bits entre 150-180 kbps)\n"\
"                 standard:  codificao VBR, qualidade alta\n"\
"                 (taxa de bits entre 170-210 kbps)\n"\
"                 extreme: codificao VBR, qualidade muito alta\n"\
"                 (taxa de bits entre 200-240 kbps)\n"\
"                 insane:  codificao CBR, ajuste para a mais alta qualidade\n"\
"                 (taxa de bits fixa em 320 kbps)\n"\
"                 <8-320>: codificao ABR com a taxa de bits em kbps dada.\n\n"

// open.c, stream.c:
#define MSGTR_CdDevNotfound "Dispositivo de CD-ROM '%s' no encontrado!\n"
#define MSGTR_ErrTrackSelect "Erro selecionando trilha do VCD!"
#define MSGTR_ReadSTDIN "Lendo de stdin...\n"
#define MSGTR_UnableOpenURL "Impossvel abrir URL: %s\n"
#define MSGTR_ConnToServer "Conecatado ao servidor: %s\n"
#define MSGTR_FileNotFound "Arquivo no encontrado: '%s'\n"

#define MSGTR_SMBInitError "Impossvel inicializar biblioteca libsmbclient: %d\n"
#define MSGTR_SMBFileNotFound "Impossvel abrir da \"lan\": '%s'\n"
#define MSGTR_SMBNotCompiled "MPlayer no foi compilado com suporte a leitura de SMB\n"

#define MSGTR_CantOpenDVD "Impossvel abrir dispositivo de DVD: %s\n"
#define MSGTR_DVDwait "Lendo estrutura do disco, por favor aguarde...\n"
#define MSGTR_DVDnumTitles "Existem %d ttulos neste DVD.\n"
#define MSGTR_DVDinvalidTitle "Nmero do ttulo do DVD invlido: %d\n"
#define MSGTR_DVDnumChapters "Existem %d captulos neste ttulo de DVD.\n"
#define MSGTR_DVDinvalidChapter "Nmero do captulo do DVD invlido: %d\n"
#define MSGTR_DVDnumAngles "Existem %d anglos neste ttulo de DVD.\n"
#define MSGTR_DVDinvalidAngle "Nmero do anglo do DVD invlido: %d\n"
#define MSGTR_DVDnoIFO "Impossvel abrir o arquivo IFO para o ttulo de DVD %d.\n"
#define MSGTR_DVDnoVOBs "Impossvel abrir ttulo VOBS (VTS_%02d_1.VOB).\n"
#define MSGTR_DVDopenOk "DVD aberto com xito!\n"

// demuxer.c, demux_*.c:
#define MSGTR_AudioStreamRedefined "AVISO! Cabealho %d da trilha de audio redefinido!\n"
#define MSGTR_VideoStreamRedefined "AVISO! Cabealho %d da trilha de vdeo redefinido!\n"
#define MSGTR_TooManyAudioInBuffer "\nMuitos pacotes de audio no buffer: (%d em %d bytes).\n"
#define MSGTR_TooManyVideoInBuffer "\nMuitos pacotes de audio no buffer: (%d em %d bytes).\n"
#define MSGTR_MaybeNI "Talvez voc esteja reproduzindo um fluxo/arquivo no-entrelaado ou o codec falhou?\n" \
		      "Para arquivos .AVI, tente forar um modo no-entrelaado com a opo -ni.\n"
#define MSGTR_SwitchToNi "\nDetectado .AVI mau entrelaado - mudando para o modo -ni!\n"
#define MSGTR_Detected_XXX_FileFormat "Detectado formato de arquivo %s!\n"
#define MSGTR_DetectedAudiofile "Detectado arquivo de audio!\n"
#define MSGTR_NotSystemStream "Formato do fluxo no MPEG System... (pode ser um fluxo de transporte?)\n"
#define MSGTR_InvalidMPEGES "Fluxo MPEG-ES invlido??? Contacte o autor, pode ser um bug :(\n"
#define MSGTR_FormatNotRecognized "======= Desculpe, este formato de arquivo no  reconhecido/suportado ========\n"\
				  "== Se este arquivo  um fluxo AVI, ASF ou MPEG, por favor contacte o autor ==\n"
#define MSGTR_MissingVideoStream "Nenhuma trilha de vdeo encontrado!\n"
#define MSGTR_MissingAudioStream "Nenhuma trilha de audio encontrado -> sem som\n"
#define MSGTR_MissingVideoStreamBug "Trilha de vdeo faltando!? Contacte o autor, pode ser um bug :(\n"

#define MSGTR_DoesntContainSelectedStream "demux: Arquivo no contm a trilha de audio ou vdeo selecionado.\n"

#define MSGTR_NI_Forced "Forado"
#define MSGTR_NI_Detected "Detectado"
#define MSGTR_NI_Message "%s formato de arquivo AVI NO ENTRELAADO!\n"

#define MSGTR_UsingNINI "Usando formato quebrado no-entrelaado do arquivo AVI!\n"
#define MSGTR_CouldntDetFNo "Impossvel determinar o nmero de quadros (para busca absoluta)  \n"
#define MSGTR_CantSeekRawAVI "Impossvel buscar em fluxos de .AVI brutos! (ndice requerido, tente com a opo -idx!)  \n"
#define MSGTR_CantSeekFile "Impossvel buscar neste arquivo!  \n"

#define MSGTR_EncryptedVOB "Arquivo VOB encriptado (compilado sem suporte a libcss)! Leia DOCS/cd-dvd.html.\n"
#define MSGTR_EncryptedVOBauth "Fluxo encriptado mas voc no requisitou autenticao!!\n"

#define MSGTR_MOVcomprhdr "MOV: Cabealhos comprimidos no suportados (ainda)!\n"
#define MSGTR_MOVvariableFourCC "MOV: Advertncia! Varivel FOURCC detectada!?\n"
#define MSGTR_MOVtooManyTrk "MOV: Advertncia! Trilhas demais!"
#define MSGTR_FoundAudioStream "==> Trilha de audio encontrada: %d\n"
#define MSGTR_FoundVideoStream "==> Trilha de video encontrada: %d\n"
#define MSGTR_DetectedTV "TV detectada! ;-)\n"
#define MSGTR_ErrorOpeningOGGDemuxer "Impossvel abrir o demuxer ogg\n"
#define MSGTR_ASFSearchingForAudioStream "ASF: Procurando por trilha de audio (id:%d)\n"
#define MSGTR_CannotOpenAudioStream "Impossvel abrir trilha de audio: %s\n"
#define MSGTR_CannotOpenSubtitlesStream "Impossvel abrir trilha de legendas: %s\n"
#define MSGTR_OpeningAudioDemuxerFailed "Falha ao abrir demuxer de audio: %s\n"
#define MSGTR_OpeningSubtitlesDemuxerFailed "Falha ao abrir demuxer de legendas: %s\n"
#define MSGTR_TVInputNotSeekable "Entrada de TV no aceita busca! (Provavelmente a busca ser pra mudar de canal ;)\n"
#define MSGTR_DemuxerInfoAlreadyPresent "Informao %s do demuxer j presente!\n"
#define MSGTR_ClipInfo "Informaes do clip:\n"

#define MSGTR_LeaveTelecineMode "\ndemux_mpg: Sequncia progressiva detectada, deixando modo 3:2 TELECINE\n"
#define MSGTR_EnterTelecineMode "\ndemux_mpg: modo 3:2 TELECINE detectado, habilitando telecine fx inverso. Quadros por segundo mudado para  %5.3f!  \n"

// dec_video.c & dec_audio.c:
#define MSGTR_CantOpenCodec "Impossvel abrir codec\n"
#define MSGTR_CantCloseCodec "Impossvel fechar codec\n"

#define MSGTR_MissingDLLcodec "ERRO: Impossvel abrir o codec DirectShow %s requerido.\n"
#define MSGTR_ACMiniterror "Impossvel carregar/inicializar o codec Win32/ACM AUDIO (arquivo DLL faltando?).\n"
#define MSGTR_MissingLAVCcodec "Impossvel encontrar codec '%s' em libavcodec...\n"

#define MSGTR_MpegNoSequHdr "MPEG: FATAL: EOF enquanto procurando pelo cabealho da sequncia\n"
#define MSGTR_CannotReadMpegSequHdr "FATAL: Impossvel ler cabealho da sequncia!\n"
#define MSGTR_CannotReadMpegSequHdrEx "FATAL: Impossvel ler exteno do cabealho da sequncia!\n"
#define MSGTR_BadMpegSequHdr "MPEG: Cabealho da sequncia mau!\n"
#define MSGTR_BadMpegSequHdrEx "MPEG: Extenso do cabealho da sequncia mau!\n"

#define MSGTR_ShMemAllocFail "Impossvel alocar memria compartilhada\n"
#define MSGTR_CantAllocAudioBuf "Impossvel alocate buffer da sada de audio\n"

#define MSGTR_UnknownAudio "Desconhecido/faltando formato de audio -> sem som\n"

#define MSGTR_UsingExternalPP "[PP] Usando filtro de ps processamento externo, mximo q = %d\n"
#define MSGTR_UsingCodecPP "[PP] Usando ps processamento do codec, mximo q = = %d\n"
#define MSGTR_VideoAttributeNotSupportedByVO_VD "Atributo de vdeo '%s' no  suportado pelo vo & vd selecionado! \n"
#define MSGTR_VideoCodecFamilyNotAvailableStr "Famlia [%s] (vfm=%s) do codec de video no disponvel (habilite na hora da compilao!)\n"
#define MSGTR_AudioCodecFamilyNotAvailableStr "Famlia [%s] (afm=%s) do codec de audio no disponvel (habilite na hora da compilao!)\n"
#define MSGTR_OpeningVideoDecoder "Abrindo decodificador de vdeo: [%s] %s\n"
#define MSGTR_OpeningAudioDecoder "Abrindo decodificador de audio: [%s] %s\n"
#define MSGTR_UninitVideoStr "finalizando vdeo: %s\n"
#define MSGTR_UninitAudioStr "finalizando audio: %s\n"
#define MSGTR_VDecoderInitFailed "Falha na incializao do VDecoder :(\n"
#define MSGTR_ADecoderInitFailed "Falha na incializao do ADecoder :(\n"
#define MSGTR_ADecoderPreinitFailed "Falha na pr-inicializao do ADecoder :(\n"
#define MSGTR_AllocatingBytesForInputBuffer "dec_audio: Aclocando %d bytes para o buffer de entrtada\n"
#define MSGTR_AllocatingBytesForOutputBuffer "dec_audio: Alocando %d + %d = %d bytes para o buffer de sada\n"

// LIRC:
#define MSGTR_SettingUpLIRC "Configurando o suporte a lirc...\n"
#define MSGTR_LIRCdisabled "No ser possvel utilizar o seu controle remoto\n"
#define MSGTR_LIRCopenfailed "Falha na abertura do suporte a lirc!\n"
#define MSGTR_LIRCcfgerr "Falha ao ler o arquivo de configurao do LIRC %s.\n"

// vf.c
#define MSGTR_CouldNotFindVideoFilter "Filtro de vdeo '%s' no encontrado\n"
#define MSGTR_CouldNotOpenVideoFilter "Impossvel abrir o filtro de vdeo '%s'\n"
#define MSGTR_OpeningVideoFilter "Abrindo filtro de vdeo: "
#define MSGTR_CannotFindColorspace "Impossvel encontrar um \"colorspace\" comum, mesmo inserindo \"scale\" :(\n"

// vd.c
#define MSGTR_CodecDidNotSet "VDec: codec no configurou sh->disp_w e sh->disp_h, tentando soluo alternativa!\n"
#define MSGTR_VoConfigRequest "VDec: configurao vo pedida - %d x %d (preferido csp: %s)\n"
#define MSGTR_CouldNotFindColorspace "Impossvel encotrar \"colorspace\" similar - retentando com -vop scale...\n"
#define MSGTR_MovieAspectIsSet "Aspecto do filme   %.2f:1 - pr-redimensionando para corrigir o aspecto do filme.\n"
#define MSGTR_MovieAspectUndefined "Aspecto do filme  indefinido - nenhum pr-redimensionamento aplicado.\n"

// ====================== GUI messages/buttons ========================

#ifdef HAVE_NEW_GUI

// --- labels ---
#define MSGTR_About "Sobre"
#define MSGTR_FileSelect "Selecionar arquivo ..."
#define MSGTR_SubtitleSelect "Selecionar legenda ..."
#define MSGTR_OtherSelect "Selecionar ..."
#define MSGTR_AudioFileSelect "Selecionar canal de audio externo ..."
#define MSGTR_FontSelect "Selecionar fonte ..."
#define MSGTR_PlayList "Lista de reproduo"
#define MSGTR_Equalizer "Equalizador"
#define MSGTR_SkinBrowser "Skins"
#define MSGTR_Network "Rede ..."
#define MSGTR_Preferences "Preferncias"
#define MSGTR_OSSPreferences "Configurao do driver OSS"
#define MSGTR_SDLPreferences "Configurao do driver SDL"
#define MSGTR_NoMediaOpened "Nenhuma mdia aberta."
#define MSGTR_VCDTrack "Trilha do VCD %d"
#define MSGTR_NoChapter "Nenhum captulo"
#define MSGTR_Chapter "Captulo %d"
#define MSGTR_NoFileLoaded "Nenhum arquivo carregado"

// --- buttons ---
#define MSGTR_Ok "OK"
#define MSGTR_Cancel "Cancelar"
#define MSGTR_Add "Adicionar"
#define MSGTR_Remove "Remover"
#define MSGTR_Clear "Limpar"
#define MSGTR_Config "Configuraes"
#define MSGTR_ConfigDriver "Configuraes do driver"
#define MSGTR_Browse "Procurar"

// --- error messages ---
#define MSGTR_NEMDB "Desculpe, sem memria suficiente para desenhar o buffer."
#define MSGTR_NEMFMR "Desculpe, sem memria suficiente para rendenizar o menu."
#define MSGTR_IDFGCVD "Desculpe, eu no encontrei um driver sada de vdeo compatvel com GUI."
#define MSGTR_NEEDLAVCFAME "Desculpe, voc no pode reproduzir arquivos no-MPEG com o seu dispositivo DXR3/H+ sem recodificar.\nPor favor habilite lavc ou fame na configurao do DXR3/H+."

// --- skin loader error messages
#define MSGTR_SKIN_ERRORMESSAGE "[skin] erro no arquivo de configurao do skin na linha: %s"
#define MSGTR_SKIN_WARNING1 "[skin] aviso no arquivo de configurao do skin na linha %d: widget encontrado mas antes de \"section\" no encontrado ( %s )"
#define MSGTR_SKIN_WARNING2 "[skin] aviso no arquivo de configurao do skin na linha %d: widget encontrado mas antes de \"subsection\" no encontrtado (%s)"
#define MSGTR_SKIN_WARNING3 "[skin] aviso no arquivo de configurao do skin na linha %d: esta sub-seo no  suportada por este widget (%s)"
#define MSGTR_SKIN_BITMAP_16bit  "16 bit ou menor profundidade de cores no suportado ( %s ).\n"
#define MSGTR_SKIN_BITMAP_FileNotFound  "arquivo no encontrado ( %s )\n"
#define MSGTR_SKIN_BITMAP_BMPReadError "erro na leitura do bmp ( %s )\n"
#define MSGTR_SKIN_BITMAP_TGAReadError "erro na leitura do tga ( %s )\n"
#define MSGTR_SKIN_BITMAP_PNGReadError "erro na leitura do png ( %s )\n"
#define MSGTR_SKIN_BITMAP_RLENotSupported "tga empacotado RLE no suportado ( %s )\n"
#define MSGTR_SKIN_BITMAP_UnknownFileType "tipo de arquivo desconhecido ( %s )\n"
#define MSGTR_SKIN_BITMAP_ConvertError "erro na converso 24 bit para 32 bit ( %s )\n"
#define MSGTR_SKIN_BITMAP_UnknownMessage "mensagem desconhecida: %s\n"
#define MSGTR_SKIN_FONT_NotEnoughtMemory "memria insuficiente\n"
#define MSGTR_SKIN_FONT_TooManyFontsDeclared "muitas fontes declaradas\n"
#define MSGTR_SKIN_FONT_FontFileNotFound "arquivo da fonte no encontrado\n"
#define MSGTR_SKIN_FONT_FontImageNotFound "arquivo de imagem da fonte no encontrado\n"
#define MSGTR_SKIN_FONT_NonExistentFontID "indentificador de fonte no existente ( %s )\n"
#define MSGTR_SKIN_UnknownParameter "parmetro desconhecido ( %s )\n"
#define MSGTR_SKINBROWSER_NotEnoughMemory "[skinbrowser] memria insuficiente.\n"
#define MSGTR_SKIN_SKINCFG_SkinNotFound "Skin no encontrado ( %s ).\n"
#define MSGTR_SKIN_SKINCFG_SkinCfgReadError "Erro na leitura do arquivo de configurao do skin ( %s ).\n"
#define MSGTR_SKIN_LABEL "Skins:"

// --- gtk menus
#define MSGTR_MENU_AboutMPlayer "Sobre o MPlayer"
#define MSGTR_MENU_Open "Abrir ..."
#define MSGTR_MENU_PlayFile "Reproduzir arquivo ..."
#define MSGTR_MENU_PlayVCD "Reproduzir VCD ..."
#define MSGTR_MENU_PlayDVD "Reproduzir DVD ..."
#define MSGTR_MENU_PlayURL "Reproduzir URL ..."
#define MSGTR_MENU_LoadSubtitle "Carregar legenda ..."
#define MSGTR_MENU_DropSubtitle "Descartar legenda ..."
#define MSGTR_MENU_LoadExternAudioFile "Carregar arquivo de audio externo ..."
#define MSGTR_MENU_Playing "Reproduo"
#define MSGTR_MENU_Play "Reproduzir"
#define MSGTR_MENU_Pause "Pausar"
#define MSGTR_MENU_Stop "Parar"
#define MSGTR_MENU_NextStream "Prxima faixa"
#define MSGTR_MENU_PrevStream "Faixa anterior"
#define MSGTR_MENU_Size "Tamanho"
#define MSGTR_MENU_NormalSize "Tamanho normal"
#define MSGTR_MENU_DoubleSize "Tamanho dobrado"
#define MSGTR_MENU_FullScreen "Tela cheia"
#define MSGTR_MENU_DVD "DVD"
#define MSGTR_MENU_VCD "VCD"
#define MSGTR_MENU_PlayDisc "Abrir disco ..."
#define MSGTR_MENU_ShowDVDMenu "Mostrar menu do DVD"
#define MSGTR_MENU_Titles "Ttulos"
#define MSGTR_MENU_Title "Ttulo %2d"
#define MSGTR_MENU_None "(nenhum)"
#define MSGTR_MENU_Chapters "Captulos"
#define MSGTR_MENU_Chapter "Captulo %2d"
#define MSGTR_MENU_AudioLanguages "Idiomas do audio"
#define MSGTR_MENU_SubtitleLanguages "Idiomas da legenda"
#define MSGTR_MENU_PlayList "Lista de reproduo"
#define MSGTR_MENU_SkinBrowser "Skins"
#define MSGTR_MENU_Preferences "Preferncias"
#define MSGTR_MENU_Exit "Sair ..."
#define MSGTR_MENU_Mute "Mudo"
#define MSGTR_MENU_Original "Original"
#define MSGTR_MENU_AspectRatio "Aspecto"
#define MSGTR_MENU_AudioTrack "Trilha de audio"
#define MSGTR_MENU_Track "Trilha %d"
#define MSGTR_MENU_VideoTrack "Trilha de vdeo"

// --- equalizer
#define MSGTR_EQU_Audio "Audio"
#define MSGTR_EQU_Video "Vdeo"
#define MSGTR_EQU_Contrast "Contraste: "
#define MSGTR_EQU_Brightness "Brilho: "
#define MSGTR_EQU_Hue "Cor: "
#define MSGTR_EQU_Saturation "Saturao: "
#define MSGTR_EQU_Front_Left "Frente Esquerda"
#define MSGTR_EQU_Front_Right "Frente Direita"
#define MSGTR_EQU_Back_Left "Fundo Esquerda"
#define MSGTR_EQU_Back_Right "Fundo Direita"
#define MSGTR_EQU_Center "Centro"
#define MSGTR_EQU_Bass "Grave"
#define MSGTR_EQU_All "Todos"
#define MSGTR_EQU_Channel1 "Canal 1:"
#define MSGTR_EQU_Channel2 "Canal 2:"
#define MSGTR_EQU_Channel3 "Canal 3:"
#define MSGTR_EQU_Channel4 "Canal 4:"
#define MSGTR_EQU_Channel5 "Canal 5:"
#define MSGTR_EQU_Channel6 "Canal 6:"

// --- playlist
#define MSGTR_PLAYLIST_Path "Caminho"
#define MSGTR_PLAYLIST_Selected "Arquivos selecionados"
#define MSGTR_PLAYLIST_Files "Arquivos"
#define MSGTR_PLAYLIST_DirectoryTree "rvore de diretrios"

// --- preferences
#define MSGTR_PREFERENCES_Audio "Audio"
#define MSGTR_PREFERENCES_Video "Vdeo"
#define MSGTR_PREFERENCES_SubtitleOSD "Legenda & OSD"
#define MSGTR_PREFERENCES_Codecs "Codecs & demuxer"
#define MSGTR_PREFERENCES_Misc "Misc"

#define MSGTR_PREFERENCES_None "Nenhum"
#define MSGTR_PREFERENCES_AvailableDrivers "Drivers disponveis:"
#define MSGTR_PREFERENCES_DoNotPlaySound "No reproduzir som"
#define MSGTR_PREFERENCES_NormalizeSound "Normalizar som"
#define MSGTR_PREFERENCES_EnEqualizer "Habilitar equalizador"
#define MSGTR_PREFERENCES_ExtraStereo "Habilitar extra estreo"
#define MSGTR_PREFERENCES_Coefficient "Coeficiente:"
#define MSGTR_PREFERENCES_AudioDelay "Atraso do audio"
#define MSGTR_PREFERENCES_DoubleBuffer "Habilitar duplo buffer"
#define MSGTR_PREFERENCES_DirectRender "Habilitar direct rendering"
#define MSGTR_PREFERENCES_FrameDrop "Habilitar descarte de quadros"
#define MSGTR_PREFERENCES_HFrameDrop "Habilitar descarte de quadros SEVERO (perigoso)"
#define MSGTR_PREFERENCES_Flip "Inverter imagem verticalmente"
#define MSGTR_PREFERENCES_Panscan "Panscan: "
#define MSGTR_PREFERENCES_OSDTimer "Temporizador e indicadores"
#define MSGTR_PREFERENCES_OSDProgress "Barras de progresso apenas"
#define MSGTR_PREFERENCES_OSDTimerPercentageTotalTime "Temporizador, porcentagem e tempo total"
#define MSGTR_PREFERENCES_Subtitle "Legenda:"
#define MSGTR_PREFERENCES_SUB_Delay "Atrtaso: "
#define MSGTR_PREFERENCES_SUB_FPS "FPS:"
#define MSGTR_PREFERENCES_SUB_POS "Posio: "
#define MSGTR_PREFERENCES_SUB_AutoLoad "Desabilitar auto carregamento de legendas"
#define MSGTR_PREFERENCES_SUB_Unicode "Legenda unicode"
#define MSGTR_PREFERENCES_SUB_MPSUB "Converter a legenda dada para o formato de legenda do MPlayer"
#define MSGTR_PREFERENCES_SUB_SRT "Converter a legenda dada para o formato baseado em tempo SubViewer (SRT)"
#define MSGTR_PREFERENCES_SUB_Overlap "Sobreposio da legenda"
#define MSGTR_PREFERENCES_Font "Fonte"
#define MSGTR_PREFERENCES_FontFactor "Fator da fonte:"
#define MSGTR_PREFERENCES_PostProcess "Habilitar ps-processamento"
#define MSGTR_PREFERENCES_AutoQuality "Qualidade do audio: "
#define MSGTR_PREFERENCES_NI "Usar leitor de AVI no-entrelaado"
#define MSGTR_PREFERENCES_IDX "Reconstruir tabela ndice, se necessrio"
#define MSGTR_PREFERENCES_VideoCodecFamily "Famlia do codec de vdeo:"
#define MSGTR_PREFERENCES_AudioCodecFamily "Famlia do codec de audio:"
#define MSGTR_PREFERENCES_FRAME_OSD_Level "Nvel do OSD"
#define MSGTR_PREFERENCES_FRAME_Subtitle "Legenda"
#define MSGTR_PREFERENCES_FRAME_Font "Fonte"
#define MSGTR_PREFERENCES_FRAME_PostProcess "Ps-processamento"
#define MSGTR_PREFERENCES_FRAME_CodecDemuxer "Codec & demuxer"
#define MSGTR_PREFERENCES_FRAME_Cache "Cache"
#define MSGTR_PREFERENCES_FRAME_Misc "Misc"
#define MSGTR_PREFERENCES_OSS_Device "Dispositivo:"
#define MSGTR_PREFERENCES_OSS_Mixer "Mixer:"
#define MSGTR_PREFERENCES_SDL_Driver "Driver:"
#define MSGTR_PREFERENCES_Message "Por favor lembre que voc precisa reiniciar a reproduo para algumas opes fazerem efeito!"
#define MSGTR_PREFERENCES_DXR3_VENC "Codificador de video:"
#define MSGTR_PREFERENCES_DXR3_LAVC "Usar LAVC (ffmpeg)"
#define MSGTR_PREFERENCES_DXR3_FAME "Usar FAME"
#define MSGTR_PREFERENCES_FontEncoding1 "Unicode"
#define MSGTR_PREFERENCES_FontEncoding2 "Lnguas Europias Ocidentais (ISO-8859-1)"
#define MSGTR_PREFERENCES_FontEncoding3 "Lnguas Europias Ocidentais com Euro (ISO-8859-15)"
#define MSGTR_PREFERENCES_FontEncoding4 "Linguas Europias Eslvicas/Centrais (ISO-8859-2)"
#define MSGTR_PREFERENCES_FontEncoding5 "Esperanto, Galego, Malts, Turco (ISO-8859-3)"
#define MSGTR_PREFERENCES_FontEncoding6 "Caracteres Blticos Antigos (ISO-8859-4)"
#define MSGTR_PREFERENCES_FontEncoding7 "Cirlico (ISO-8859-5)"
#define MSGTR_PREFERENCES_FontEncoding8 "rabe (ISO-8859-6)"
#define MSGTR_PREFERENCES_FontEncoding9 "Grego Moderno (ISO-8859-7)"
#define MSGTR_PREFERENCES_FontEncoding10 "Turco (ISO-8859-9)"
#define MSGTR_PREFERENCES_FontEncoding11 "Bltico (ISO-8859-13)"
#define MSGTR_PREFERENCES_FontEncoding12 "Celta (ISO-8859-14)"
#define MSGTR_PREFERENCES_FontEncoding13 "Caracteres Hebraicos (ISO-8859-8)"
#define MSGTR_PREFERENCES_FontEncoding14 "Russo (KOI8-R)"
#define MSGTR_PREFERENCES_FontEncoding15 "Ucraniano, Bielo-Russo (KOI8-U/RU)"
#define MSGTR_PREFERENCES_FontEncoding16 "Caracteres Chineses Simplificados (CP936)"
#define MSGTR_PREFERENCES_FontEncoding17 "Caracteres Chineses Tradicionais (BIG5)"
#define MSGTR_PREFERENCES_FontEncoding18 "Caracteres Japoneses (SHIFT-JIS)"
#define MSGTR_PREFERENCES_FontEncoding19 "Caracteres Coreanos (CP949)"
#define MSGTR_PREFERENCES_FontEncoding20 "Caracteres Tailandeses (CP874)"
#define MSGTR_PREFERENCES_FontEncoding21 "Windows Cirlico (CP1251)"
#define MSGTR_PREFERENCES_FontNoAutoScale "Sem auto redimensionamento"
#define MSGTR_PREFERENCES_FontPropWidth "Proporcional a largura do filme"
#define MSGTR_PREFERENCES_FontPropHeight "Proporcional a altura do filme"
#define MSGTR_PREFERENCES_FontPropDiagonal "Proporcional a diagonal do filme"
#define MSGTR_PREFERENCES_FontEncoding "Codificao:"
#define MSGTR_PREFERENCES_FontBlur "Embassar:"
#define MSGTR_PREFERENCES_FontOutLine "Contorno:"
#define MSGTR_PREFERENCES_FontTextScale "Tamanho do texto:"
#define MSGTR_PREFERENCES_FontOSDScale "Tamanho do OSD:"
#define MSGTR_PREFERENCES_Cache "Cache ligado/desligado"
#define MSGTR_PREFERENCES_CacheSize "Tamaho do cache: "
#define MSGTR_PREFERENCES_LoadFullscreen "Iniciar em tela cheia"
#define MSGTR_PREFERENCES_XSCREENSAVER "Parar XScreenSaver"
#define MSGTR_PREFERENCES_PlayBar "Habilitar barra de reproduo"
#define MSGTR_PREFERENCES_AutoSync "AutoSync ligado/desligado"
#define MSGTR_PREFERENCES_AutoSyncValue "Autosync: "
#define MSGTR_PREFERENCES_CDROMDevice "Dispositivo de CD-ROM:"
#define MSGTR_PREFERENCES_DVDDevice "Dispositivo de DVD:"
#define MSGTR_PREFERENCES_FPS "Quadros por segundo do filme:"
#define MSGTR_PREFERENCES_ShowVideoWindow "Mostrar janela do vdeo quando inativo"

#define MSGTR_ABOUT_UHU "Desenvolvimento do GUI patrocinado por UHU Linux\n"
#define MSGTR_ABOUT_CoreTeam "   Ncleo do time do MPlayer:\n"
#define MSGTR_ABOUT_AdditionalCoders "   Programadores adicionais:\n"
#define MSGTR_ABOUT_MainTesters "   Testadores principais:\n"

// --- messagebox
#define MSGTR_MSGBOX_LABEL_FatalError "Erro fatal!"
#define MSGTR_MSGBOX_LABEL_Error "Erro!"
#define MSGTR_MSGBOX_LABEL_Warning "Ateno!"

#endif
